from .............Internal.Core import Core
from .............Internal.CommandsGroup import CommandsGroup
from .............Internal import Conversions
from ............. import enums
from ............. import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ResAllocCls:
	"""ResAlloc commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("resAlloc", core, parent)

	@property
	def pattern(self):
		"""pattern commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pattern'):
			from .Pattern import PatternCls
			self._pattern = PatternCls(self._core, self._cmd_group)
		return self._pattern

	def set(self, user_alloc_px_schr: enums.EidNr5GresAllocUserAlloc, cellNull=repcap.CellNull.Default, subframeNull=repcap.SubframeNull.Default, userNull=repcap.UserNull.Default, bwPartNull=repcap.BwPartNull.Default, allocationNull=repcap.AllocationNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SCHed:CELL<CC(CH0)>:SUBF<SF(ST0)>:USER<US(DIR0)>:BWPart<BWP(GR0)>:ALLoc<AL(USER0)>:PUSCh:RESalloc \n
		Snippet: driver.source.bb.nr5G.scheduling.cell.subf.user.bwPart.alloc.pusch.resAlloc.set(user_alloc_px_schr = enums.EidNr5GresAllocUserAlloc.T0, cellNull = repcap.CellNull.Default, subframeNull = repcap.SubframeNull.Default, userNull = repcap.UserNull.Default, bwPartNull = repcap.BwPartNull.Default, allocationNull = repcap.AllocationNull.Default) \n
		Sets the resource allocation type. \n
			:param user_alloc_px_schr: T0| T1| T2
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'BwPart')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
		"""
		param = Conversions.enum_scalar_to_str(user_alloc_px_schr, enums.EidNr5GresAllocUserAlloc)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		subframeNull_cmd_val = self._cmd_group.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		allocationNull_cmd_val = self._cmd_group.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:SCHed:CELL{cellNull_cmd_val}:SUBF{subframeNull_cmd_val}:USER{userNull_cmd_val}:BWPart{bwPartNull_cmd_val}:ALLoc{allocationNull_cmd_val}:PUSCh:RESalloc {param}')

	# noinspection PyTypeChecker
	def get(self, cellNull=repcap.CellNull.Default, subframeNull=repcap.SubframeNull.Default, userNull=repcap.UserNull.Default, bwPartNull=repcap.BwPartNull.Default, allocationNull=repcap.AllocationNull.Default) -> enums.EidNr5GresAllocUserAlloc:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SCHed:CELL<CC(CH0)>:SUBF<SF(ST0)>:USER<US(DIR0)>:BWPart<BWP(GR0)>:ALLoc<AL(USER0)>:PUSCh:RESalloc \n
		Snippet: value: enums.EidNr5GresAllocUserAlloc = driver.source.bb.nr5G.scheduling.cell.subf.user.bwPart.alloc.pusch.resAlloc.get(cellNull = repcap.CellNull.Default, subframeNull = repcap.SubframeNull.Default, userNull = repcap.UserNull.Default, bwPartNull = repcap.BwPartNull.Default, allocationNull = repcap.AllocationNull.Default) \n
		Sets the resource allocation type. \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'BwPart')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:return: user_alloc_px_schr: T0| T1| T2"""
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		subframeNull_cmd_val = self._cmd_group.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		allocationNull_cmd_val = self._cmd_group.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:SCHed:CELL{cellNull_cmd_val}:SUBF{subframeNull_cmd_val}:USER{userNull_cmd_val}:BWPart{bwPartNull_cmd_val}:ALLoc{allocationNull_cmd_val}:PUSCh:RESalloc?')
		return Conversions.str_to_scalar_enum(response, enums.EidNr5GresAllocUserAlloc)

	def clone(self) -> 'ResAllocCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ResAllocCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PepCls:
	"""Pep commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pep", core, parent)

	def get_maximum(self) -> float:
		"""SCPI: SCONfiguration:BEXTension:INFO:ALIGn:PEP:MAXimum \n
		Snippet: value: float = driver.sconfiguration.bextension.info.align.pep.get_maximum() \n
		Queries the maximum peak envelope power (PEP) of the setup aligment procedure. Make sure, that the measurement device
		supports this power value. \n
			:return: max_pep: float Range: -145 to 30
		"""
		response = self._core.io.query_str('SCONfiguration:BEXTension:INFO:ALIGn:PEP:MAXimum?')
		return Conversions.str_to_float(response)

	def get_minimum(self) -> float:
		"""SCPI: SCONfiguration:BEXTension:INFO:ALIGn:PEP:MINimum \n
		Snippet: value: float = driver.sconfiguration.bextension.info.align.pep.get_minimum() \n
		Queries the start frequency of the setup aligment procedure. Make sure, that the measurement device supports this start
		frequency. \n
			:return: min_pep: float Range: -145 to 30
		"""
		response = self._core.io.query_str('SCONfiguration:BEXTension:INFO:ALIGn:PEP:MINimum?')
		return Conversions.str_to_float(response)



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PrecodingCls:
	"""Precoding commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("precoding", core, parent)

	@property
	def cbIndex(self):
		"""cbIndex commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cbIndex'):
			from .CbIndex import CbIndexCls
			self._cbIndex = CbIndexCls(self._core, self._cmd_group)
		return self._cbIndex

	@property
	def napUsed(self):
		"""napUsed commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_napUsed'):
			from .NapUsed import NapUsedCls
			self._napUsed = NapUsedCls(self._core, self._cmd_group)
		return self._napUsed

	@property
	def noLayers(self):
		"""noLayers commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_noLayers'):
			from .NoLayers import NoLayersCls
			self._noLayers = NoLayersCls(self._core, self._cmd_group)
		return self._noLayers

	def clone(self) -> 'PrecodingCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PrecodingCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Utilities import trim_str_response
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DlistCls:
	"""Dlist commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dlist", core, parent)

	def set(self, ssch_data_list: str, userNull=repcap.UserNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<US(CH0)>:SSCH:DLISt \n
		Snippet: driver.source.bb.nr5G.ubwp.user.ssch.dlist.set(ssch_data_list = 'abc', userNull = repcap.UserNull.Default) \n
		Selects a data list as a PSSCH data source.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Select a data list as data source ([:SOURce<hw>]:BB:NR5G:UBWP:USER<us>:SSCH:DATA) . \n
			:param ssch_data_list: string String containing the path and file name of the data list.
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
		"""
		param = Conversions.value_to_quoted_str(ssch_data_list)
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:SSCH:DLISt {param}')

	def get(self, userNull=repcap.UserNull.Default) -> str:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<US(CH0)>:SSCH:DLISt \n
		Snippet: value: str = driver.source.bb.nr5G.ubwp.user.ssch.dlist.get(userNull = repcap.UserNull.Default) \n
		Selects a data list as a PSSCH data source.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Select a data list as data source ([:SOURce<hw>]:BB:NR5G:UBWP:USER<us>:SSCH:DATA) . \n
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:return: ssch_data_list: No help available"""
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:SSCH:DLISt?')
		return trim_str_response(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ApMapCls:
	"""ApMap commands group definition. 13 total commands, 13 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("apMap", core, parent)

	@property
	def ap1000Map(self):
		"""ap1000Map commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ap1000Map'):
			from .Ap1000Map import Ap1000MapCls
			self._ap1000Map = Ap1000MapCls(self._core, self._cmd_group)
		return self._ap1000Map

	@property
	def ap100Map(self):
		"""ap100Map commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ap100Map'):
			from .Ap100Map import Ap100MapCls
			self._ap100Map = Ap100MapCls(self._core, self._cmd_group)
		return self._ap100Map

	@property
	def ap1010Map(self):
		"""ap1010Map commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ap1010Map'):
			from .Ap1010Map import Ap1010MapCls
			self._ap1010Map = Ap1010MapCls(self._core, self._cmd_group)
		return self._ap1010Map

	@property
	def ap1020Map(self):
		"""ap1020Map commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ap1020Map'):
			from .Ap1020Map import Ap1020MapCls
			self._ap1020Map = Ap1020MapCls(self._core, self._cmd_group)
		return self._ap1020Map

	@property
	def ap10Map(self):
		"""ap10Map commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ap10Map'):
			from .Ap10Map import Ap10MapCls
			self._ap10Map = Ap10MapCls(self._core, self._cmd_group)
		return self._ap10Map

	@property
	def ap200Map(self):
		"""ap200Map commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ap200Map'):
			from .Ap200Map import Ap200MapCls
			self._ap200Map = Ap200MapCls(self._core, self._cmd_group)
		return self._ap200Map

	@property
	def ap201Map(self):
		"""ap201Map commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ap201Map'):
			from .Ap201Map import Ap201MapCls
			self._ap201Map = Ap201MapCls(self._core, self._cmd_group)
		return self._ap201Map

	@property
	def ap20Map(self):
		"""ap20Map commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ap20Map'):
			from .Ap20Map import Ap20MapCls
			self._ap20Map = Ap20MapCls(self._core, self._cmd_group)
		return self._ap20Map

	@property
	def ap21Map(self):
		"""ap21Map commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ap21Map'):
			from .Ap21Map import Ap21MapCls
			self._ap21Map = Ap21MapCls(self._core, self._cmd_group)
		return self._ap21Map

	@property
	def ap40Map(self):
		"""ap40Map commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ap40Map'):
			from .Ap40Map import Ap40MapCls
			self._ap40Map = Ap40MapCls(self._core, self._cmd_group)
		return self._ap40Map

	@property
	def ap41Map(self):
		"""ap41Map commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ap41Map'):
			from .Ap41Map import Ap41MapCls
			self._ap41Map = Ap41MapCls(self._core, self._cmd_group)
		return self._ap41Map

	@property
	def ap42Map(self):
		"""ap42Map commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ap42Map'):
			from .Ap42Map import Ap42MapCls
			self._ap42Map = Ap42MapCls(self._core, self._cmd_group)
		return self._ap42Map

	@property
	def ap43Map(self):
		"""ap43Map commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ap43Map'):
			from .Ap43Map import Ap43MapCls
			self._ap43Map = Ap43MapCls(self._core, self._cmd_group)
		return self._ap43Map

	def clone(self) -> 'ApMapCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ApMapCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.RepeatedCapability import RepeatedCapability
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NotchCls:
	"""Notch commands group definition. 8 total commands, 4 Subgroups, 3 group commands
	Repeated Capability: NotchFilter, default value after init: NotchFilter.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("notch", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_notchFilter_get', 'repcap_notchFilter_set', repcap.NotchFilter.Nr1)

	def repcap_notchFilter_set(self, notchFilter: repcap.NotchFilter) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to NotchFilter.Default
		Default value after init: NotchFilter.Nr1"""
		self._cmd_group.set_repcap_enum_value(notchFilter)

	def repcap_notchFilter_get(self) -> repcap.NotchFilter:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def apply(self):
		"""apply commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_apply'):
			from .Apply import ApplyCls
			self._apply = ApplyCls(self._core, self._cmd_group)
		return self._apply

	@property
	def bandwidth(self):
		"""bandwidth commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_bandwidth'):
			from .Bandwidth import BandwidthCls
			self._bandwidth = BandwidthCls(self._core, self._cmd_group)
		return self._bandwidth

	@property
	def frequency(self):
		"""frequency commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import FrequencyCls
			self._frequency = FrequencyCls(self._core, self._cmd_group)
		return self._frequency

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	def get_clock(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:DVB:NOTCh:CLOCk \n
		Snippet: value: int = driver.source.bb.dvb.notch.get_clock() \n
		Queries the current clock frequency of the waveform signal. Works like the command [:SOURce<hw>]:BB:ARBitrary:CLOCk. \n
			:return: clock_freq: integer Range: 400 to 2000E6
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:NOTCh:CLOCk?')
		return Conversions.str_to_int(response)

	def get_count(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:DVB:NOTCh:COUNt \n
		Snippet: value: int = driver.source.bb.dvb.notch.get_count() \n
		Sets the number of notches. \n
			:return: num_of_notch: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:NOTCh:COUNt?')
		return Conversions.str_to_int(response)

	def set_count(self, num_of_notch: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:DVB:NOTCh:COUNt \n
		Snippet: driver.source.bb.dvb.notch.set_count(num_of_notch = 1) \n
		Sets the number of notches. \n
			:param num_of_notch: integer Range: 1 to 25
		"""
		param = Conversions.decimal_value_to_str(num_of_notch)
		self._core.io.write(f'SOURce<HwInstance>:BB:DVB:NOTCh:COUNt {param}')

	def get_value(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:DVB:NOTCh \n
		Snippet: value: bool = driver.source.bb.dvb.notch.get_value() \n
		Enables or disables the notch filter. \n
			:return: notch_state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:NOTCh?')
		return Conversions.str_to_bool(response)

	def set_value(self, notch_state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:DVB:NOTCh \n
		Snippet: driver.source.bb.dvb.notch.set_value(notch_state = False) \n
		Enables or disables the notch filter. \n
			:param notch_state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(notch_state)
		self._core.io.write(f'SOURce<HwInstance>:BB:DVB:NOTCh {param}')

	def clone(self) -> 'NotchCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = NotchCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AesKeyCls:
	"""AesKey commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("aesKey", core, parent)

	# noinspection PyTypeChecker
	def get_length(self) -> enums.OsnmaAes:
		"""SCPI: [SOURce<HW>]:BB:GNSS:GALileo:OSNMa:AESKey:LENGth \n
		Snippet: value: enums.OsnmaAes = driver.source.bb.gnss.galileo.osnma.aesKey.get_length() \n
		No command help available \n
			:return: key_length: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:GALileo:OSNMa:AESKey:LENGth?')
		return Conversions.str_to_scalar_enum(response, enums.OsnmaAes)

	def set_length(self, key_length: enums.OsnmaAes) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:GALileo:OSNMa:AESKey:LENGth \n
		Snippet: driver.source.bb.gnss.galileo.osnma.aesKey.set_length(key_length = enums.OsnmaAes.AES128) \n
		No command help available \n
			:param key_length: No help available
		"""
		param = Conversions.enum_scalar_to_str(key_length, enums.OsnmaAes)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:GALileo:OSNMa:AESKey:LENGth {param}')



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal.RepeatedCapability import RepeatedCapability
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CsirsCls:
	"""Csirs commands group definition. 8 total commands, 8 Subgroups, 0 group commands
	Repeated Capability: CsiRefSignal, default value after init: CsiRefSignal.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("csirs", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_csiRefSignal_get', 'repcap_csiRefSignal_set', repcap.CsiRefSignal.Nr1)

	def repcap_csiRefSignal_set(self, csiRefSignal: repcap.CsiRefSignal) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to CsiRefSignal.Default
		Default value after init: CsiRefSignal.Nr1"""
		self._cmd_group.set_repcap_enum_value(csiRefSignal)

	def repcap_csiRefSignal_get(self) -> repcap.CsiRefSignal:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def nzConfig(self):
		"""nzConfig commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nzConfig'):
			from .NzConfig import NzConfigCls
			self._nzConfig = NzConfigCls(self._core, self._cmd_group)
		return self._nzConfig

	@property
	def nzqOffset(self):
		"""nzqOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nzqOffset'):
			from .NzqOffset import NzqOffsetCls
			self._nzqOffset = NzqOffsetCls(self._core, self._cmd_group)
		return self._nzqOffset

	@property
	def nzsCid(self):
		"""nzsCid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nzsCid'):
			from .NzsCid import NzsCidCls
			self._nzsCid = NzsCidCls(self._core, self._cmd_group)
		return self._nzsCid

	@property
	def nzsfOffset(self):
		"""nzsfOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nzsfOffset'):
			from .NzsfOffset import NzsfOffsetCls
			self._nzsfOffset = NzsfOffsetCls(self._core, self._cmd_group)
		return self._nzsfOffset

	@property
	def zp(self):
		"""zp commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_zp'):
			from .Zp import ZpCls
			self._zp = ZpCls(self._core, self._cmd_group)
		return self._zp

	@property
	def zpDelta(self):
		"""zpDelta commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_zpDelta'):
			from .ZpDelta import ZpDeltaCls
			self._zpDelta = ZpDeltaCls(self._core, self._cmd_group)
		return self._zpDelta

	@property
	def zpi(self):
		"""zpi commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_zpi'):
			from .Zpi import ZpiCls
			self._zpi = ZpiCls(self._core, self._cmd_group)
		return self._zpi

	@property
	def zpt(self):
		"""zpt commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_zpt'):
			from .Zpt import ZptCls
			self._zpt = ZptCls(self._core, self._cmd_group)
		return self._zpt

	def clone(self) -> 'CsirsCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CsirsCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, mode: enums.SystConfOutpMapMatMode, iqConnector=repcap.IqConnector.Default) -> None:
		"""SCPI: SCONfiguration:OUTPut:MAPPing:BBMM<CH>:MODE \n
		Snippet: driver.sconfiguration.output.mapping.bbmm.mode.set(mode = enums.SystConfOutpMapMatMode.ADD, iqConnector = repcap.IqConnector.Default) \n
		Enables routing of multiple streams to the same output physical connector and defines the way the streams are internally
		processed. \n
			:param mode: SINGle| ADD| MULTiplex ADD enabled for the RF, I/Q OUT and BBMM outputs MULTiplex enabled for the BBMM outputs and method RsSmw.Sconfiguration.Output.modeDIGMux
			:param iqConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bbmm')
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.SystConfOutpMapMatMode)
		iqConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(iqConnector, repcap.IqConnector)
		self._core.io.write(f'SCONfiguration:OUTPut:MAPPing:BBMM{iqConnector_cmd_val}:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, iqConnector=repcap.IqConnector.Default) -> enums.SystConfOutpMapMatMode:
		"""SCPI: SCONfiguration:OUTPut:MAPPing:BBMM<CH>:MODE \n
		Snippet: value: enums.SystConfOutpMapMatMode = driver.sconfiguration.output.mapping.bbmm.mode.get(iqConnector = repcap.IqConnector.Default) \n
		Enables routing of multiple streams to the same output physical connector and defines the way the streams are internally
		processed. \n
			:param iqConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bbmm')
			:return: mode: SINGle| ADD| MULTiplex ADD enabled for the RF, I/Q OUT and BBMM outputs MULTiplex enabled for the BBMM outputs and method RsSmw.Sconfiguration.Output.modeDIGMux"""
		iqConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(iqConnector, repcap.IqConnector)
		response = self._core.io.query_str(f'SCONfiguration:OUTPut:MAPPing:BBMM{iqConnector_cmd_val}:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.SystConfOutpMapMatMode)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CorrectionCls:
	"""Correction commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("correction", core, parent)

	def get_file(self) -> str:
		"""SCPI: [SOURce<HW>]:EFRontend:EXTDevice:CORRection:FILE \n
		Snippet: value: str = driver.source.efrontend.extDevice.correction.get_file() \n
		Selects an existing correction file, e.g. to compensate for cable losses. Selectable files have file extension *.s2p. \n
			:return: filename: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:EFRontend:EXTDevice:CORRection:FILE?')
		return trim_str_response(response)

	def set_file(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:EFRontend:EXTDevice:CORRection:FILE \n
		Snippet: driver.source.efrontend.extDevice.correction.set_file(filename = 'abc') \n
		Selects an existing correction file, e.g. to compensate for cable losses. Selectable files have file extension *.s2p. \n
			:param filename: string
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:EFRontend:EXTDevice:CORRection:FILE {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:EFRontend:EXTDevice:CORRection:STATe \n
		Snippet: value: bool = driver.source.efrontend.extDevice.correction.get_state() \n
		Activates correction of the RF signal for different RF signal frequencies. Activation requires loading of a valid
		correction file. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:EFRontend:EXTDevice:CORRection:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:EFRontend:EXTDevice:CORRection:STATe \n
		Snippet: driver.source.efrontend.extDevice.correction.set_state(state = False) \n
		Activates correction of the RF signal for different RF signal frequencies. Activation requires loading of a valid
		correction file. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:EFRontend:EXTDevice:CORRection:STATe {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, mark_mode: enums.MarkMode, output=repcap.Output.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:V5G:TRIGger:OUTPut<CH>:MODE \n
		Snippet: driver.source.bb.v5G.trigger.output.mode.set(mark_mode = enums.MarkMode.RESTart, output = repcap.Output.Default) \n
		Defines the signal for the selected marker output. \n
			:param mark_mode: RESTart
			:param output: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
		"""
		param = Conversions.enum_scalar_to_str(mark_mode, enums.MarkMode)
		output_cmd_val = self._cmd_group.get_repcap_cmd_value(output, repcap.Output)
		self._core.io.write(f'SOURce<HwInstance>:BB:V5G:TRIGger:OUTPut{output_cmd_val}:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, output=repcap.Output.Default) -> enums.MarkMode:
		"""SCPI: [SOURce<HW>]:BB:V5G:TRIGger:OUTPut<CH>:MODE \n
		Snippet: value: enums.MarkMode = driver.source.bb.v5G.trigger.output.mode.get(output = repcap.Output.Default) \n
		Defines the signal for the selected marker output. \n
			:param output: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
			:return: mark_mode: RESTart"""
		output_cmd_val = self._cmd_group.get_repcap_cmd_value(output, repcap.Output)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:V5G:TRIGger:OUTPut{output_cmd_val}:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.MarkMode)



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Types import DataType
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SlapCls:
	"""Slap commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("slap", core, parent)

	def set(self, lap: List[str], bitcount: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:PCONfiguration:SLAP \n
		Snippet: driver.source.bb.btooth.econfiguration.pconfiguration.slap.set(lap = ['rawAbc1', 'rawAbc2', 'rawAbc3'], bitcount = 1) \n
		Sets the lower address part (LAP) of Bluetooth device address. Commands for the advertising ..:ALAP, initiating ..:ILAP,
		scanning ..:SLAP PDUs of advertising channel type are provided. In addition, a command is provided for scanner's or
		initiator's target device address to which the advertisement is directed ..:TLAP. \n
			:param lap: numeric
			:param bitcount: integer Range: 24 to 24
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle.as_open_list('lap', lap, DataType.RawStringList, None), ArgSingle('bitcount', bitcount, DataType.Integer))
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PCONfiguration:SLAP {param}'.rstrip())

	# noinspection PyTypeChecker
	class SlapStruct(StructBase):
		"""Response structure. Fields: \n
			- Lap: List[str]: numeric
			- Bitcount: int: integer Range: 24 to 24"""
		__meta_args_list = [
			ArgStruct('Lap', DataType.RawStringList, None, False, True, 1),
			ArgStruct.scalar_int('Bitcount')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Lap: List[str] = None
			self.Bitcount: int = None

	def get(self) -> SlapStruct:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:PCONfiguration:SLAP \n
		Snippet: value: SlapStruct = driver.source.bb.btooth.econfiguration.pconfiguration.slap.get() \n
		Sets the lower address part (LAP) of Bluetooth device address. Commands for the advertising ..:ALAP, initiating ..:ILAP,
		scanning ..:SLAP PDUs of advertising channel type are provided. In addition, a command is provided for scanner's or
		initiator's target device address to which the advertisement is directed ..:TLAP. \n
			:return: structure: for return value, see the help for SlapStruct structure arguments."""
		return self._core.io.query_struct(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PCONfiguration:SLAP?', self.__class__.SlapStruct())



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.RepeatedCapability import RepeatedCapability
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PacketCls:
	"""Packet commands group definition. 13 total commands, 11 Subgroups, 0 group commands
	Repeated Capability: Packet, default value after init: Packet.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("packet", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_packet_get', 'repcap_packet_set', repcap.Packet.Nr1)

	def repcap_packet_set(self, packet: repcap.Packet) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Packet.Default
		Default value after init: Packet.Nr1"""
		self._cmd_group.set_repcap_enum_value(packet)

	def repcap_packet_get(self) -> repcap.Packet:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def ccoding(self):
		"""ccoding commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ccoding'):
			from .Ccoding import CcodingCls
			self._ccoding = CcodingCls(self._core, self._cmd_group)
		return self._ccoding

	@property
	def count(self):
		"""count commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_count'):
			from .Count import CountCls
			self._count = CountCls(self._core, self._cmd_group)
		return self._count

	@property
	def data(self):
		"""data commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_data'):
			from .Data import DataCls
			self._data = DataCls(self._core, self._cmd_group)
		return self._data

	@property
	def drate(self):
		"""drate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_drate'):
			from .Drate import DrateCls
			self._drate = DrateCls(self._core, self._cmd_group)
		return self._drate

	@property
	def fcs(self):
		"""fcs commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_fcs'):
			from .Fcs import FcsCls
			self._fcs = FcsCls(self._core, self._cmd_group)
		return self._fcs

	@property
	def gain(self):
		"""gain commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_gain'):
			from .Gain import GainCls
			self._gain = GainCls(self._core, self._cmd_group)
		return self._gain

	@property
	def infinite(self):
		"""infinite commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_infinite'):
			from .Infinite import InfiniteCls
			self._infinite = InfiniteCls(self._core, self._cmd_group)
		return self._infinite

	@property
	def modulation(self):
		"""modulation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_modulation'):
			from .Modulation import ModulationCls
			self._modulation = ModulationCls(self._core, self._cmd_group)
		return self._modulation

	@property
	def psize(self):
		"""psize commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_psize'):
			from .Psize import PsizeCls
			self._psize = PsizeCls(self._core, self._cmd_group)
		return self._psize

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def subPackets(self):
		"""subPackets commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_subPackets'):
			from .SubPackets import SubPacketsCls
			self._subPackets = SubPacketsCls(self._core, self._cmd_group)
		return self._subPackets

	def clone(self) -> 'PacketCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PacketCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HoldCls:
	"""Hold commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("hold", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	def reset(self, iqConnector=repcap.IqConnector.Default) -> None:
		"""SCPI: [SOURce]:IQ:OUTPut:DIGital:BBMM<CH>:OFLow:HOLD:RESet \n
		Snippet: driver.source.iq.output.digital.bbmm.oflow.hold.reset(iqConnector = repcap.IqConnector.Default) \n
		Resets the overflow hold state and LED. \n
			:param iqConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bbmm')
		"""
		iqConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(iqConnector, repcap.IqConnector)
		self._core.io.write(f'SOURce:IQ:OUTPut:DIGital:BBMM{iqConnector_cmd_val}:OFLow:HOLD:RESet')

	def reset_with_opc(self, iqConnector=repcap.IqConnector.Default, opc_timeout_ms: int = -1) -> None:
		iqConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(iqConnector, repcap.IqConnector)
		"""SCPI: [SOURce]:IQ:OUTPut:DIGital:BBMM<CH>:OFLow:HOLD:RESet \n
		Snippet: driver.source.iq.output.digital.bbmm.oflow.hold.reset_with_opc(iqConnector = repcap.IqConnector.Default) \n
		Resets the overflow hold state and LED. \n
		Same as reset, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
			:param iqConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bbmm')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce:IQ:OUTPut:DIGital:BBMM{iqConnector_cmd_val}:OFLow:HOLD:RESet', opc_timeout_ms)

	def clone(self) -> 'HoldCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = HoldCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SfdCls:
	"""Sfd commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sfd", core, parent)

	def get_usr_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:HUWB:SFD:USRState \n
		Snippet: value: bool = driver.source.bb.huwb.sfd.get_usr_state() \n
		Enables using SFD indices SFD_5, SFD_6 and SFD_7. \n
			:return: user_state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:HUWB:SFD:USRState?')
		return Conversions.str_to_bool(response)

	def set_usr_state(self, user_state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:HUWB:SFD:USRState \n
		Snippet: driver.source.bb.huwb.sfd.set_usr_state(user_state = False) \n
		Enables using SFD indices SFD_5, SFD_6 and SFD_7. \n
			:param user_state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(user_state)
		self._core.io.write(f'SOURce<HwInstance>:BB:HUWB:SFD:USRState {param}')

	# noinspection PyTypeChecker
	def get_value(self) -> enums.HrpUwbSfdIndex:
		"""SCPI: [SOURce<HW>]:BB:HUWB:SFD \n
		Snippet: value: enums.HrpUwbSfdIndex = driver.source.bb.huwb.sfd.get_value() \n
		Sets the start-of-frame delimiter (SFD) symbol sequence. The indices represent SFD symbol sequences with SFD lengths as
		listed in Table 'SFD: indices and lengths'. SFD: indices and lengths
			Table Header:  \n
			- Index / SFD_0 / SFD_1 / SFD_2 / SFD_3 / SFD_4 / SFD_5 / SFD_6 / SFD_7 / SFD_8
			- SFD / 0 / 1 / 2 / 3 / 4 / User1 / User2 / User3 / Legacy
			- SFD length / 8 / 4 / 8 / 16 / 32 / 8 / 16 / 64 / 8
		Using indices SFD_5, SFD_6 and SFD_7 requires [:SOURce<hw>]:BB:HUWB:SFD:USRState 1. \n
			:return: sfd_index: SFD_0| SFD_1| SFD_2| SFD_3| SFD_4| SFD_5| SFD_6| SFD_7| SFD_8
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:HUWB:SFD?')
		return Conversions.str_to_scalar_enum(response, enums.HrpUwbSfdIndex)

	def set_value(self, sfd_index: enums.HrpUwbSfdIndex) -> None:
		"""SCPI: [SOURce<HW>]:BB:HUWB:SFD \n
		Snippet: driver.source.bb.huwb.sfd.set_value(sfd_index = enums.HrpUwbSfdIndex.SFD_0) \n
		Sets the start-of-frame delimiter (SFD) symbol sequence. The indices represent SFD symbol sequences with SFD lengths as
		listed in Table 'SFD: indices and lengths'. SFD: indices and lengths
			Table Header:  \n
			- Index / SFD_0 / SFD_1 / SFD_2 / SFD_3 / SFD_4 / SFD_5 / SFD_6 / SFD_7 / SFD_8
			- SFD / 0 / 1 / 2 / 3 / 4 / User1 / User2 / User3 / Legacy
			- SFD length / 8 / 4 / 8 / 16 / 32 / 8 / 16 / 64 / 8
		Using indices SFD_5, SFD_6 and SFD_7 requires [:SOURce<hw>]:BB:HUWB:SFD:USRState 1. \n
			:param sfd_index: SFD_0| SFD_1| SFD_2| SFD_3| SFD_4| SFD_5| SFD_6| SFD_7| SFD_8
		"""
		param = Conversions.enum_scalar_to_str(sfd_index, enums.HrpUwbSfdIndex)
		self._core.io.write(f'SOURce<HwInstance>:BB:HUWB:SFD {param}')



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FileCls:
	"""File commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("file", core, parent)

	def set(self, filename: str, index=repcap.Index.Default) -> None:
		"""SCPI: SCONfiguration:EXTernal:DIGital<CH>:REMote:INITialization:PREDefined:FILE \n
		Snippet: driver.sconfiguration.external.digital.remote.initialization.predefined.file.set(filename = 'abc', index = repcap.Index.Default) \n
		No command help available \n
			:param filename: No help available
			:param index: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Digital')
		"""
		param = Conversions.value_to_quoted_str(filename)
		index_cmd_val = self._cmd_group.get_repcap_cmd_value(index, repcap.Index)
		self._core.io.write(f'SCONfiguration:EXTernal:DIGital{index_cmd_val}:REMote:INITialization:PREDefined:FILE {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LogGenCls:
	"""LogGen commands group definition. 25 total commands, 2 Subgroups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("logGen", core, parent)

	@property
	def downlink(self):
		"""downlink commands group. 3 Sub-classes, 6 commands."""
		if not hasattr(self, '_downlink'):
			from .Downlink import DownlinkCls
			self._downlink = DownlinkCls(self._core, self._cmd_group)
		return self._downlink

	@property
	def uplink(self):
		"""uplink commands group. 3 Sub-classes, 9 commands."""
		if not hasattr(self, '_uplink'):
			from .Uplink import UplinkCls
			self._uplink = UplinkCls(self._core, self._cmd_group)
		return self._uplink

	def get_gs_log_file(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:GSLogfile \n
		Snippet: value: bool = driver.source.bb.eutra.logGen.get_gs_log_file() \n
		Enables the generation of a summary logfile. \n
			:return: gen_sum_log: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:LOGGen:GSLogfile?')
		return Conversions.str_to_bool(response)

	def set_gs_log_file(self, gen_sum_log: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:GSLogfile \n
		Snippet: driver.source.bb.eutra.logGen.set_gs_log_file(gen_sum_log = False) \n
		Enables the generation of a summary logfile. \n
			:param gen_sum_log: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(gen_sum_log)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:LOGGen:GSLogfile {param}')

	def get_lfp(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:LFP \n
		Snippet: value: str = driver.source.bb.eutra.logGen.get_lfp() \n
		Sets the preamble added to the file name. See 'Filenames' for a description of the file naming conventions. \n
			:return: preamble: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:LOGGen:LFP?')
		return trim_str_response(response)

	def set_lfp(self, preamble: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:LFP \n
		Snippet: driver.source.bb.eutra.logGen.set_lfp(preamble = 'abc') \n
		Sets the preamble added to the file name. See 'Filenames' for a description of the file naming conventions. \n
			:param preamble: string
		"""
		param = Conversions.value_to_quoted_str(preamble)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:LOGGen:LFP {param}')

	def get_output(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:OUTPut \n
		Snippet: value: str = driver.source.bb.eutra.logGen.get_output() \n
		Selects the network directory the logged files are stored in. \n
			:return: output_path: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:LOGGen:OUTPut?')
		return trim_str_response(response)

	def set_output(self, output_path: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:OUTPut \n
		Snippet: driver.source.bb.eutra.logGen.set_output(output_path = 'abc') \n
		Selects the network directory the logged files are stored in. \n
			:param output_path: No help available
		"""
		param = Conversions.value_to_quoted_str(output_path)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:LOGGen:OUTPut {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:STATe \n
		Snippet: value: bool = driver.source.bb.eutra.logGen.get_state() \n
		Enables/disables logfile generation. \n
			:return: logging_state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:LOGGen:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, logging_state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:STATe \n
		Snippet: driver.source.bb.eutra.logGen.set_state(logging_state = False) \n
		Enables/disables logfile generation. \n
			:param logging_state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(logging_state)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:LOGGen:STATe {param}')

	def clone(self) -> 'LogGenCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = LogGenCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CountersCls:
	"""Counters commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("counters", core, parent)

	def reset(self) -> None:
		"""SCPI: SYSTem:COMMunicate:BB<HW>:QSFP:NETWork:DIAGnostic:COUNters:RESet \n
		Snippet: driver.system.communicate.bb.qsfp.network.diagnostic.counters.reset() \n
		No command help available \n
		"""
		self._core.io.write(f'SYSTem:COMMunicate:BB<HwInstance>:QSFP:NETWork:DIAGnostic:COUNters:RESet')

	def reset_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: SYSTem:COMMunicate:BB<HW>:QSFP:NETWork:DIAGnostic:COUNters:RESet \n
		Snippet: driver.system.communicate.bb.qsfp.network.diagnostic.counters.reset_with_opc() \n
		No command help available \n
		Same as reset, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SYSTem:COMMunicate:BB<HwInstance>:QSFP:NETWork:DIAGnostic:COUNters:RESet', opc_timeout_ms)

	def get_value(self) -> List[float]:
		"""SCPI: SYSTem:COMMunicate:BB<HW>:QSFP:NETWork:DIAGnostic:COUNters \n
		Snippet: value: List[float] = driver.system.communicate.bb.qsfp.network.diagnostic.counters.get_value() \n
		No command help available \n
			:return: hs_net_statistics: No help available
		"""
		response = self._core.io.query_bin_or_ascii_float_list('SYSTem:COMMunicate:BB<HwInstance>:QSFP:NETWork:DIAGnostic:COUNters?')
		return response



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DschCls:
	"""Dsch commands group definition. 19 total commands, 19 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dsch", core, parent)

	@property
	def anfMode(self):
		"""anfMode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_anfMode'):
			from .AnfMode import AnfModeCls
			self._anfMode = AnfModeCls(self._core, self._cmd_group)
		return self._anfMode

	@property
	def ccoding(self):
		"""ccoding commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ccoding'):
			from .Ccoding import CcodingCls
			self._ccoding = CcodingCls(self._core, self._cmd_group)
		return self._ccoding

	@property
	def cdin(self):
		"""cdin commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cdin'):
			from .Cdin import CdinCls
			self._cdin = CdinCls(self._core, self._cmd_group)
		return self._cdin

	@property
	def cods(self):
		"""cods commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cods'):
			from .Cods import CodsCls
			self._cods = CodsCls(self._core, self._cmd_group)
		return self._cods

	@property
	def da02(self):
		"""da02 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_da02'):
			from .Da02 import Da02Cls
			self._da02 = Da02Cls(self._core, self._cmd_group)
		return self._da02

	@property
	def dait(self):
		"""dait commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dait'):
			from .Dait import DaitCls
			self._dait = DaitCls(self._core, self._cmd_group)
		return self._dait

	@property
	def data(self):
		"""data commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_data'):
			from .Data import DataCls
			self._data = DataCls(self._core, self._cmd_group)
		return self._data

	@property
	def daul(self):
		"""daul commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_daul'):
			from .Daul import DaulCls
			self._daul = DaulCls(self._core, self._cmd_group)
		return self._daul

	@property
	def dlist(self):
		"""dlist commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dlist'):
			from .Dlist import DlistCls
			self._dlist = DlistCls(self._core, self._cmd_group)
		return self._dlist

	@property
	def hartInd(self):
		"""hartInd commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hartInd'):
			from .HartInd import HartIndCls
			self._hartInd = HartIndCls(self._core, self._cmd_group)
		return self._hartInd

	@property
	def initPattern(self):
		"""initPattern commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_initPattern'):
			from .InitPattern import InitPatternCls
			self._initPattern = InitPatternCls(self._core, self._cmd_group)
		return self._initPattern

	@property
	def nrbs(self):
		"""nrbs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nrbs'):
			from .Nrbs import NrbsCls
			self._nrbs = NrbsCls(self._core, self._cmd_group)
		return self._nrbs

	@property
	def nssf(self):
		"""nssf commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nssf'):
			from .Nssf import NssfCls
			self._nssf = NssfCls(self._core, self._cmd_group)
		return self._nssf

	@property
	def pattern(self):
		"""pattern commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pattern'):
			from .Pattern import PatternCls
			self._pattern = PatternCls(self._core, self._cmd_group)
		return self._pattern

	@property
	def ph1F(self):
		"""ph1F commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ph1F'):
			from .Ph1F import Ph1FCls
			self._ph1F = Ph1FCls(self._core, self._cmd_group)
		return self._ph1F

	@property
	def psscDyn(self):
		"""psscDyn commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_psscDyn'):
			from .PsscDyn import PsscDynCls
			self._psscDyn = PsscDynCls(self._core, self._cmd_group)
		return self._psscDyn

	@property
	def rbis(self):
		"""rbis commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rbis'):
			from .Rbis import RbisCls
			self._rbis = RbisCls(self._core, self._cmd_group)
		return self._rbis

	@property
	def scgw(self):
		"""scgw commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scgw'):
			from .Scgw import ScgwCls
			self._scgw = ScgwCls(self._core, self._cmd_group)
		return self._scgw

	@property
	def scrambling(self):
		"""scrambling commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_scrambling'):
			from .Scrambling import ScramblingCls
			self._scrambling = ScramblingCls(self._core, self._cmd_group)
		return self._scrambling

	def clone(self) -> 'DschCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DschCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Utilities import trim_str_response
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FileCls:
	"""File commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("file", core, parent)

	def set(self, filename: str, path=repcap.Path.Default) -> None:
		"""SCPI: SCONfiguration:EXTernal:RF<CH>:REMote:INITialization:FILE \n
		Snippet: driver.sconfiguration.external.rf.remote.initialization.file.set(filename = 'abc', path = repcap.Path.Default) \n
		Queries the currently selected initialization file. \n
			:param filename: string filename with file extension (*.iec)
			:param path: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Rf')
		"""
		param = Conversions.value_to_quoted_str(filename)
		path_cmd_val = self._cmd_group.get_repcap_cmd_value(path, repcap.Path)
		self._core.io.write(f'SCONfiguration:EXTernal:RF{path_cmd_val}:REMote:INITialization:FILE {param}')

	def get(self, path=repcap.Path.Default) -> str:
		"""SCPI: SCONfiguration:EXTernal:RF<CH>:REMote:INITialization:FILE \n
		Snippet: value: str = driver.sconfiguration.external.rf.remote.initialization.file.get(path = repcap.Path.Default) \n
		Queries the currently selected initialization file. \n
			:param path: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Rf')
			:return: filename: string filename with file extension (*.iec)"""
		path_cmd_val = self._cmd_group.get_repcap_cmd_value(path, repcap.Path)
		response = self._core.io.query_str(f'SCONfiguration:EXTernal:RF{path_cmd_val}:REMote:INITialization:FILE?')
		return trim_str_response(response)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HschCls:
	"""Hsch commands group definition. 4 total commands, 4 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("hsch", core, parent)

	@property
	def cvpb(self):
		"""cvpb commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cvpb'):
			from .Cvpb import CvpbCls
			self._cvpb = CvpbCls(self._core, self._cmd_group)
		return self._cvpb

	@property
	def prsr(self):
		"""prsr commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_prsr'):
			from .Prsr import PrsrCls
			self._prsr = PrsrCls(self._core, self._cmd_group)
		return self._prsr

	@property
	def psbs(self):
		"""psbs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_psbs'):
			from .Psbs import PsbsCls
			self._psbs = PsbsCls(self._core, self._cmd_group)
		return self._psbs

	@property
	def rvParameter(self):
		"""rvParameter commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rvParameter'):
			from .RvParameter import RvParameterCls
			self._rvParameter = RvParameterCls(self._core, self._cmd_group)
		return self._rvParameter

	def clone(self) -> 'HschCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = HschCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from .........Internal.RepeatedCapability import RepeatedCapability
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AddressCls:
	"""Address commands group definition. 2 total commands, 1 Subgroups, 1 group commands
	Repeated Capability: AddressField, default value after init: AddressField.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("address", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_addressField_get', 'repcap_addressField_set', repcap.AddressField.Nr1)

	def repcap_addressField_set(self, addressField: repcap.AddressField) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to AddressField.Default
		Default value after init: AddressField.Nr1"""
		self._cmd_group.set_repcap_enum_value(addressField)

	def repcap_addressField_get(self) -> repcap.AddressField:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	def set(self, address: List[str], frameBlock=repcap.FrameBlock.Default, userIx=repcap.UserIx.Default, addressField=repcap.AddressField.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:[USER<DI>]:MAC:ADDRess<ST> \n
		Snippet: driver.source.bb.wlnn.fblock.user.mac.address.set(address = ['rawAbc1', 'rawAbc2', 'rawAbc3'], frameBlock = repcap.FrameBlock.Default, userIx = repcap.UserIx.Default, addressField = repcap.AddressField.Default) \n
		The command enters the value of the address fields 1 ... 4. Exactly 48 bits must be entered. Each address is 6 bytes (48
		bit) long. The addresses can be entered in hexadecimal form in the entry field of each address field.
		The least significant byte (LSB) is in left notation. \n
			:param address: integer Range: #H000000000000,48 to #HFFFFFFFFFFFF,48
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:param addressField: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Address')
		"""
		param = Conversions.list_to_csv_str(address)
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		addressField_cmd_val = self._cmd_group.get_repcap_cmd_value(addressField, repcap.AddressField)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:USER{userIx_cmd_val}:MAC:ADDRess{addressField_cmd_val} {param}')

	def get(self, frameBlock=repcap.FrameBlock.Default, userIx=repcap.UserIx.Default, addressField=repcap.AddressField.Default) -> List[str]:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:[USER<DI>]:MAC:ADDRess<ST> \n
		Snippet: value: List[str] = driver.source.bb.wlnn.fblock.user.mac.address.get(frameBlock = repcap.FrameBlock.Default, userIx = repcap.UserIx.Default, addressField = repcap.AddressField.Default) \n
		The command enters the value of the address fields 1 ... 4. Exactly 48 bits must be entered. Each address is 6 bytes (48
		bit) long. The addresses can be entered in hexadecimal form in the entry field of each address field.
		The least significant byte (LSB) is in left notation. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:param addressField: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Address')
			:return: address: integer Range: #H000000000000,48 to #HFFFFFFFFFFFF,48"""
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		addressField_cmd_val = self._cmd_group.get_repcap_cmd_value(addressField, repcap.AddressField)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:USER{userIx_cmd_val}:MAC:ADDRess{addressField_cmd_val}?')
		return Conversions.str_to_str_list(response)

	def clone(self) -> 'AddressCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AddressCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, iab_state: bool, output=repcap.Output.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TRIGger:OUTPut<CH>:IAB:STATe \n
		Snippet: driver.source.bb.nr5G.trigger.output.iab.state.set(iab_state = False, output = repcap.Output.Default) \n
		Turns usage of the IAB frame format on and off. \n
			:param iab_state: 1| ON| 0| OFF
			:param output: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
		"""
		param = Conversions.bool_to_str(iab_state)
		output_cmd_val = self._cmd_group.get_repcap_cmd_value(output, repcap.Output)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:TRIGger:OUTPut{output_cmd_val}:IAB:STATe {param}')

	def get(self, output=repcap.Output.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TRIGger:OUTPut<CH>:IAB:STATe \n
		Snippet: value: bool = driver.source.bb.nr5G.trigger.output.iab.state.get(output = repcap.Output.Default) \n
		Turns usage of the IAB frame format on and off. \n
			:param output: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
			:return: iab_state: No help available"""
		output_cmd_val = self._cmd_group.get_repcap_cmd_value(output, repcap.Output)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:TRIGger:OUTPut{output_cmd_val}:IAB:STATe?')
		return Conversions.str_to_bool(response)



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Types import DataType
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct
from ......Internal.ArgSingleList import ArgSingleList
from ......Internal.ArgSingle import ArgSingle
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IselectCls:
	"""Iselect commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("iselect", core, parent)

	def set(self, instr_name: List[str], rf_path: str = None, iqConnector=repcap.IqConnector.Default) -> None:
		"""SCPI: SCONfiguration:EXTernal:BBMM<CH>:REMote:ISELect \n
		Snippet: driver.sconfiguration.external.bbmm.remote.iselect.set(instr_name = ['abc1', 'abc2', 'abc3'], rf_path = 'abc', iqConnector = repcap.IqConnector.Default) \n
		Selects an external instrument for the selected connector. \n
			:param instr_name: String Instrument alias name, as retrieved with the command method RsSmw.Sconfiguration.External.Remote.listPy. The name can also be defined with the command method RsSmw.Sconfiguration.External.Remote.Add.set.
			:param rf_path: String Determines the used RF output of the external instrument.
			:param iqConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bbmm')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle.as_open_list('instr_name', instr_name, DataType.StringList, None), ArgSingle('rf_path', rf_path, DataType.String, None, is_optional=True))
		iqConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(iqConnector, repcap.IqConnector)
		self._core.io.write(f'SCONfiguration:EXTernal:BBMM{iqConnector_cmd_val}:REMote:ISELect {param}'.rstrip())

	# noinspection PyTypeChecker
	class IselectStruct(StructBase):
		"""Response structure. Fields: \n
			- Instr_Name: List[str]: String Instrument alias name, as retrieved with the command [CMDLINKRESOLVED Sconfiguration.External.Remote#ListPy CMDLINKRESOLVED]. The name can also be defined with the command [CMDLINKRESOLVED Sconfiguration.External.Remote.Add#set CMDLINKRESOLVED].
			- Rf_Path: str: String Determines the used RF output of the external instrument."""
		__meta_args_list = [
			ArgStruct('Instr_Name', DataType.StringList, None, False, True, 1),
			ArgStruct.scalar_str('Rf_Path')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Instr_Name: List[str] = None
			self.Rf_Path: str = None

	def get(self, iqConnector=repcap.IqConnector.Default) -> IselectStruct:
		"""SCPI: SCONfiguration:EXTernal:BBMM<CH>:REMote:ISELect \n
		Snippet: value: IselectStruct = driver.sconfiguration.external.bbmm.remote.iselect.get(iqConnector = repcap.IqConnector.Default) \n
		Selects an external instrument for the selected connector. \n
			:param iqConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bbmm')
			:return: structure: for return value, see the help for IselectStruct structure arguments."""
		iqConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(iqConnector, repcap.IqConnector)
		return self._core.io.query_struct(f'SCONfiguration:EXTernal:BBMM{iqConnector_cmd_val}:REMote:ISELect?', self.__class__.IselectStruct())



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Types import DataType
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CiValueCls:
	"""CiValue commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ciValue", core, parent)

	def set(self, ci_value: List[str], bitcount: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:PCONfiguration:CIValue \n
		Snippet: driver.source.bb.btooth.econfiguration.pconfiguration.ciValue.set(ci_value = ['rawAbc1', 'rawAbc2', 'rawAbc3'], bitcount = 1) \n
		Sets the initialization value for the CRC (Cyclic Redundancy Check, 24 bits) calculation. A packet has been received
		correctly, when it has passed the CRC check. \n
			:param ci_value: numeric
			:param bitcount: integer Range: 24 to 24
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle.as_open_list('ci_value', ci_value, DataType.RawStringList, None), ArgSingle('bitcount', bitcount, DataType.Integer))
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PCONfiguration:CIValue {param}'.rstrip())

	# noinspection PyTypeChecker
	class CiValueStruct(StructBase):
		"""Response structure. Fields: \n
			- Ci_Value: List[str]: numeric
			- Bitcount: int: integer Range: 24 to 24"""
		__meta_args_list = [
			ArgStruct('Ci_Value', DataType.RawStringList, None, False, True, 1),
			ArgStruct.scalar_int('Bitcount')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Ci_Value: List[str] = None
			self.Bitcount: int = None

	def get(self) -> CiValueStruct:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:PCONfiguration:CIValue \n
		Snippet: value: CiValueStruct = driver.source.bb.btooth.econfiguration.pconfiguration.ciValue.get() \n
		Sets the initialization value for the CRC (Cyclic Redundancy Check, 24 bits) calculation. A packet has been received
		correctly, when it has passed the CRC check. \n
			:return: structure: for return value, see the help for CiValueStruct structure arguments."""
		return self._core.io.query_struct(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PCONfiguration:CIValue?', self.__class__.CiValueStruct())



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PowerCls:
	"""Power commands group definition. 10 total commands, 8 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("power", core, parent)

	@property
	def bbConf(self):
		"""bbConf commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_bbConf'):
			from .BbConf import BbConfCls
			self._bbConf = BbConfCls(self._core, self._cmd_group)
		return self._bbConf

	@property
	def bwRef(self):
		"""bwRef commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bwRef'):
			from .BwRef import BwRefCls
			self._bwRef = BwRefCls(self._core, self._cmd_group)
		return self._bwRef

	@property
	def info(self):
		"""info commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_info'):
			from .Info import InfoCls
			self._info = InfoCls(self._core, self._cmd_group)
		return self._info

	@property
	def s120K(self):
		"""s120K commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_s120K'):
			from .S120K import S120KCls
			self._s120K = S120KCls(self._core, self._cmd_group)
		return self._s120K

	@property
	def s15K(self):
		"""s15K commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_s15K'):
			from .S15K import S15KCls
			self._s15K = S15KCls(self._core, self._cmd_group)
		return self._s15K

	@property
	def s240K(self):
		"""s240K commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_s240K'):
			from .S240K import S240KCls
			self._s240K = S240KCls(self._core, self._cmd_group)
		return self._s240K

	@property
	def s30K(self):
		"""s30K commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_s30K'):
			from .S30K import S30KCls
			self._s30K = S30KCls(self._core, self._cmd_group)
		return self._s30K

	@property
	def s60K(self):
		"""s60K commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_s60K'):
			from .S60K import S60KCls
			self._s60K = S60KCls(self._core, self._cmd_group)
		return self._s60K

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.PowerModeAll:
		"""SCPI: [SOURce<HW>]:BB:NR5G:OUTPut:POWer:MODE \n
		Snippet: value: enums.PowerModeAll = driver.source.bb.nr5G.output.power.get_mode() \n
		Sets how the first output is leveled. \n
			:return: power_mode: AAS Average power in the active signal AVG Average RMS power ACTvsf Average power in the active subframes PSDConst The absolute power of a particular allocation is set by multiplying the configured power spectral density (PSD) with the bandwidth of the particular allocation. Burst The 'Burst' mode is a special case of the 'Constant PSD' mode in the sense that it computes automatically a reference bandwidth based on the chosen allocation.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:OUTPut:POWer:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.PowerModeAll)

	def set_mode(self, power_mode: enums.PowerModeAll) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:OUTPut:POWer:MODE \n
		Snippet: driver.source.bb.nr5G.output.power.set_mode(power_mode = enums.PowerModeAll.AAS) \n
		Sets how the first output is leveled. \n
			:param power_mode: AAS Average power in the active signal AVG Average RMS power ACTvsf Average power in the active subframes PSDConst The absolute power of a particular allocation is set by multiplying the configured power spectral density (PSD) with the bandwidth of the particular allocation. Burst The 'Burst' mode is a special case of the 'Constant PSD' mode in the sense that it computes automatically a reference bandwidth based on the chosen allocation.
		"""
		param = Conversions.enum_scalar_to_str(power_mode, enums.PowerModeAll)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:OUTPut:POWer:MODE {param}')

	def get_rsbw(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:NR5G:OUTPut:POWer:RSBW \n
		Snippet: value: float = driver.source.bb.nr5G.output.power.get_rsbw() \n
		Sets the reference bandwidth used by the leveling of the output signal at the first output. \n
			:return: ref_system_bw: float Range: 15E3 to 400E6
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:OUTPut:POWer:RSBW?')
		return Conversions.str_to_float(response)

	def set_rsbw(self, ref_system_bw: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:OUTPut:POWer:RSBW \n
		Snippet: driver.source.bb.nr5G.output.power.set_rsbw(ref_system_bw = 1.0) \n
		Sets the reference bandwidth used by the leveling of the output signal at the first output. \n
			:param ref_system_bw: float Range: 15E3 to 400E6
		"""
		param = Conversions.decimal_value_to_str(ref_system_bw)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:OUTPut:POWer:RSBW {param}')

	def clone(self) -> 'PowerCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PowerCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ProtectionCls:
	"""Protection commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("protection", core, parent)

	def clear(self) -> None:
		"""SCPI: OUTPut<HW>:PROTection:CLEar \n
		Snippet: driver.output.protection.clear() \n
		Resets the protective circuit after it has been tripped. To define the output state, use the command method RsSmw.Output.
		State.value. \n
		"""
		self._core.io.write(f'OUTPut<HwInstance>:PROTection:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: OUTPut<HW>:PROTection:CLEar \n
		Snippet: driver.output.protection.clear_with_opc() \n
		Resets the protective circuit after it has been tripped. To define the output state, use the command method RsSmw.Output.
		State.value. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'OUTPut<HwInstance>:PROTection:CLEar', opc_timeout_ms)

	def get_state(self) -> bool:
		"""SCPI: OUTPut<HW>:PROTection:STATe \n
		Snippet: value: bool = driver.output.protection.get_state() \n
		Attenuates the RF output signal for about 40 dB to protect external devices against internal signals. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('OUTPut<HwInstance>:PROTection:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: OUTPut<HW>:PROTection:STATe \n
		Snippet: driver.output.protection.set_state(state = False) \n
		Attenuates the RF output signal for about 40 dB to protect external devices against internal signals. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'OUTPut<HwInstance>:PROTection:STATe {param}')

	def get_tripped(self) -> bool:
		"""SCPI: OUTPut<HW>:PROTection:TRIPped \n
		Snippet: value: bool = driver.output.protection.get_tripped() \n
		Queries the state of the protective circuit. \n
			:return: tripped: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('OUTPut<HwInstance>:PROTection:TRIPped?')
		return Conversions.str_to_bool(response)



from .............Internal.Core import Core
from .............Internal.CommandsGroup import CommandsGroup
from .............Internal import Conversions
from ............. import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IntlCls:
	"""Intl commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("intl", core, parent)

	def set(self, interlace: int, cellNull=repcap.CellNull.Default, subframeNull=repcap.SubframeNull.Default, userNull=repcap.UserNull.Default, bwPartNull=repcap.BwPartNull.Default, allocationNull=repcap.AllocationNull.Default, interlaceNull=repcap.InterlaceNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SCHed:CELL<CC(CH0)>:SUBF<SF(ST0)>:USER<US(DIR0)>:BWPart<BWP(GR0)>:ALLoc<AL(USER0)>:PUSCh:INT<IL(S2US0)>:INTL \n
		Snippet: driver.source.bb.nr5G.scheduling.cell.subf.user.bwPart.alloc.pusch.int.intl.set(interlace = 1, cellNull = repcap.CellNull.Default, subframeNull = repcap.SubframeNull.Default, userNull = repcap.UserNull.Default, bwPartNull = repcap.BwPartNull.Default, allocationNull = repcap.AllocationNull.Default, interlaceNull = repcap.InterlaceNull.Default) \n
		Defines the interlace value for PUSCH allocations. \n
			:param interlace: integer Range: 0 to 9
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'BwPart')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:param interlaceNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Int')
		"""
		param = Conversions.decimal_value_to_str(interlace)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		subframeNull_cmd_val = self._cmd_group.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		allocationNull_cmd_val = self._cmd_group.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		interlaceNull_cmd_val = self._cmd_group.get_repcap_cmd_value(interlaceNull, repcap.InterlaceNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:SCHed:CELL{cellNull_cmd_val}:SUBF{subframeNull_cmd_val}:USER{userNull_cmd_val}:BWPart{bwPartNull_cmd_val}:ALLoc{allocationNull_cmd_val}:PUSCh:INT{interlaceNull_cmd_val}:INTL {param}')

	def get(self, cellNull=repcap.CellNull.Default, subframeNull=repcap.SubframeNull.Default, userNull=repcap.UserNull.Default, bwPartNull=repcap.BwPartNull.Default, allocationNull=repcap.AllocationNull.Default, interlaceNull=repcap.InterlaceNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SCHed:CELL<CC(CH0)>:SUBF<SF(ST0)>:USER<US(DIR0)>:BWPart<BWP(GR0)>:ALLoc<AL(USER0)>:PUSCh:INT<IL(S2US0)>:INTL \n
		Snippet: value: int = driver.source.bb.nr5G.scheduling.cell.subf.user.bwPart.alloc.pusch.int.intl.get(cellNull = repcap.CellNull.Default, subframeNull = repcap.SubframeNull.Default, userNull = repcap.UserNull.Default, bwPartNull = repcap.BwPartNull.Default, allocationNull = repcap.AllocationNull.Default, interlaceNull = repcap.InterlaceNull.Default) \n
		Defines the interlace value for PUSCH allocations. \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'BwPart')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:param interlaceNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Int')
			:return: interlace: integer Range: 0 to 9"""
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		subframeNull_cmd_val = self._cmd_group.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		allocationNull_cmd_val = self._cmd_group.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		interlaceNull_cmd_val = self._cmd_group.get_repcap_cmd_value(interlaceNull, repcap.InterlaceNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:SCHed:CELL{cellNull_cmd_val}:SUBF{subframeNull_cmd_val}:USER{userNull_cmd_val}:BWPart{bwPartNull_cmd_val}:ALLoc{allocationNull_cmd_val}:PUSCh:INT{interlaceNull_cmd_val}:INTL?')
		return Conversions.str_to_int(response)



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Types import DataType
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SvNumberCls:
	"""SvNumber commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("svNumber", core, parent)

	def set(self, sv_number: List[str], bitcount: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:PCONfiguration:SVNumber \n
		Snippet: driver.source.bb.btooth.econfiguration.pconfiguration.svNumber.set(sv_number = ['rawAbc1', 'rawAbc2', 'rawAbc3'], bitcount = 1) \n
		Sets a unique value for each implementation or revision of an implementation of the Bluetooth Controller. A 16-bit value
		is set. Note: This parameter is relevant for data frame configuration and for the packet type: LL_VERSION_IND. \n
			:param sv_number: numeric
			:param bitcount: integer Range: 16 to 16
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle.as_open_list('sv_number', sv_number, DataType.RawStringList, None), ArgSingle('bitcount', bitcount, DataType.Integer))
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PCONfiguration:SVNumber {param}'.rstrip())

	# noinspection PyTypeChecker
	class SvNumberStruct(StructBase):
		"""Response structure. Fields: \n
			- Sv_Number: List[str]: numeric
			- Bitcount: int: integer Range: 16 to 16"""
		__meta_args_list = [
			ArgStruct('Sv_Number', DataType.RawStringList, None, False, True, 1),
			ArgStruct.scalar_int('Bitcount')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Sv_Number: List[str] = None
			self.Bitcount: int = None

	def get(self) -> SvNumberStruct:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:PCONfiguration:SVNumber \n
		Snippet: value: SvNumberStruct = driver.source.bb.btooth.econfiguration.pconfiguration.svNumber.get() \n
		Sets a unique value for each implementation or revision of an implementation of the Bluetooth Controller. A 16-bit value
		is set. Note: This parameter is relevant for data frame configuration and for the packet type: LL_VERSION_IND. \n
			:return: structure: for return value, see the help for SvNumberStruct structure arguments."""
		return self._core.io.query_struct(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PCONfiguration:SVNumber?', self.__class__.SvNumberStruct())



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PconfigCls:
	"""Pconfig commands group definition. 32 total commands, 5 Subgroups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pconfig", core, parent)

	@property
	def hda(self):
		"""hda commands group. 7 Sub-classes, 9 commands."""
		if not hasattr(self, '_hda'):
			from .Hda import HdaCls
			self._hda = HdaCls(self._core, self._cmd_group)
		return self._hda

	@property
	def hdb(self):
		"""hdb commands group. 1 Sub-classes, 2 commands."""
		if not hasattr(self, '_hdb'):
			from .Hdb import HdbCls
			self._hdb = HdbCls(self._core, self._cmd_group)
		return self._hdb

	@property
	def lhdr(self):
		"""lhdr commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_lhdr'):
			from .Lhdr import LhdrCls
			self._lhdr = LhdrCls(self._core, self._cmd_group)
		return self._lhdr

	@property
	def psk(self):
		"""psk commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_psk'):
			from .Psk import PskCls
			self._psk = PskCls(self._core, self._cmd_group)
		return self._psk

	@property
	def uconfig(self):
		"""uconfig commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_uconfig'):
			from .Uconfig import UconfigCls
			self._uconfig = UconfigCls(self._core, self._cmd_group)
		return self._uconfig

	def get_bsb_number(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:WLAY:PCONfig:BSBNumber \n
		Snippet: value: int = driver.source.bb.wlay.pconfig.get_bsb_number() \n
		Sets the minimum duration of data. \n
			:return: brp_min_sc_blk_num: integer Range: 1 to 18
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:WLAY:PCONfig:BSBNumber?')
		return Conversions.str_to_int(response)

	def set_bsb_number(self, brp_min_sc_blk_num: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLAY:PCONfig:BSBNumber \n
		Snippet: driver.source.bb.wlay.pconfig.set_bsb_number(brp_min_sc_blk_num = 1) \n
		Sets the minimum duration of data. \n
			:param brp_min_sc_blk_num: integer Range: 1 to 18
		"""
		param = Conversions.decimal_value_to_str(brp_min_sc_blk_num)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLAY:PCONfig:BSBNumber {param}')

	def get_csd_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:WLAY:PCONfig:CSDState \n
		Snippet: value: bool = driver.source.bb.wlay.pconfig.get_csd_state() \n
		Activates cyclic shift diversity (CSD) . \n
			:return: csd_state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:WLAY:PCONfig:CSDState?')
		return Conversions.str_to_bool(response)

	def set_csd_state(self, csd_state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLAY:PCONfig:CSDState \n
		Snippet: driver.source.bb.wlay.pconfig.set_csd_state(csd_state = False) \n
		Activates cyclic shift diversity (CSD) . \n
			:param csd_state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(csd_state)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLAY:PCONfig:CSDState {param}')

	def get_ss_number(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:WLAY:PCONfig:SSNumber \n
		Snippet: value: int = driver.source.bb.wlay.pconfig.get_ss_number() \n
		Queries the number of spatial streams. \n
			:return: ss_num: integer Range: 1 to 8
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:WLAY:PCONfig:SSNumber?')
		return Conversions.str_to_int(response)

	def set_ss_number(self, ss_num: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLAY:PCONfig:SSNumber \n
		Snippet: driver.source.bb.wlay.pconfig.set_ss_number(ss_num = 1) \n
		Queries the number of spatial streams. \n
			:param ss_num: integer Range: 1 to 8
		"""
		param = Conversions.decimal_value_to_str(ss_num)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLAY:PCONfig:SSNumber {param}')

	# noinspection PyTypeChecker
	def get_traggregate(self) -> enums.WlanadTrnAggregate:
		"""SCPI: [SOURce<HW>]:BB:WLAY:PCONfig:TRAGgregate \n
		Snippet: value: enums.WlanadTrnAggregate = driver.source.bb.wlay.pconfig.get_traggregate() \n
		Sets the training (TRN) aggregation mode. The modes are defined by the 1-bit TRN Aggregation field of the EDMG-Header-A2
		subfield. \n
			:return: trn_aggregate: WB| ATRN WB WidebandTRN TRN Aggregation field is 0. The bandwidth (BW) field specifies that the TRN field of the PPDU is appended on a 2.16 GHz, 4.32 GHz, 6.48 GHz, or 8.64 GHz channel. ATRN AggregationTRN TRN Aggregation field is 1. The BW field specifies that the TRN field is transmitted over a 2.16+2.16 GHz or 4.32+4.32 GHz channel.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:WLAY:PCONfig:TRAGgregate?')
		return Conversions.str_to_scalar_enum(response, enums.WlanadTrnAggregate)

	def set_traggregate(self, trn_aggregate: enums.WlanadTrnAggregate) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLAY:PCONfig:TRAGgregate \n
		Snippet: driver.source.bb.wlay.pconfig.set_traggregate(trn_aggregate = enums.WlanadTrnAggregate.ATRN) \n
		Sets the training (TRN) aggregation mode. The modes are defined by the 1-bit TRN Aggregation field of the EDMG-Header-A2
		subfield. \n
			:param trn_aggregate: WB| ATRN WB WidebandTRN TRN Aggregation field is 0. The bandwidth (BW) field specifies that the TRN field of the PPDU is appended on a 2.16 GHz, 4.32 GHz, 6.48 GHz, or 8.64 GHz channel. ATRN AggregationTRN TRN Aggregation field is 1. The BW field specifies that the TRN field is transmitted over a 2.16+2.16 GHz or 4.32+4.32 GHz channel.
		"""
		param = Conversions.enum_scalar_to_str(trn_aggregate, enums.WlanadTrnAggregate)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLAY:PCONfig:TRAGgregate {param}')

	def get_usr_number(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:WLAY:PCONfig:USRNumber \n
		Snippet: value: int = driver.source.bb.wlay.pconfig.get_usr_number() \n
		Queries the number of users. The maximum number of users equals the maximum number of spatial streams that is 8. \n
			:return: usr_num: integer Range: 1 to 8
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:WLAY:PCONfig:USRNumber?')
		return Conversions.str_to_int(response)

	def set_usr_number(self, usr_num: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLAY:PCONfig:USRNumber \n
		Snippet: driver.source.bb.wlay.pconfig.set_usr_number(usr_num = 1) \n
		Queries the number of users. The maximum number of users equals the maximum number of spatial streams that is 8. \n
			:param usr_num: integer Range: 1 to 8
		"""
		param = Conversions.decimal_value_to_str(usr_num)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLAY:PCONfig:USRNumber {param}')

	def clone(self) -> 'PconfigCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PconfigCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NumSfiCls:
	"""NumSfi commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("numSfi", core, parent)

	def set(self, num_sfi_in_dci_20: int, userNull=repcap.UserNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<US(CH0)>:NUMSfi \n
		Snippet: driver.source.bb.nr5G.ubwp.user.numSfi.set(num_sfi_in_dci_20 = 1, userNull = repcap.UserNull.Default) \n
		Sets how many slot format indicator (SFI) fields are transmitted in the DCI format 2_0. \n
			:param num_sfi_in_dci_20: integer Range: 1 to 16
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
		"""
		param = Conversions.decimal_value_to_str(num_sfi_in_dci_20)
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:NUMSfi {param}')

	def get(self, userNull=repcap.UserNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<US(CH0)>:NUMSfi \n
		Snippet: value: int = driver.source.bb.nr5G.ubwp.user.numSfi.get(userNull = repcap.UserNull.Default) \n
		Sets how many slot format indicator (SFI) fields are transmitted in the DCI format 2_0. \n
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:return: num_sfi_in_dci_20: integer Range: 1 to 16"""
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:NUMSfi?')
		return Conversions.str_to_int(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ThConfigCls:
	"""ThConfig commands group definition. 9 total commands, 4 Subgroups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("thConfig", core, parent)

	@property
	def afield(self):
		"""afield commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_afield'):
			from .Afield import AfieldCls
			self._afield = AfieldCls(self._core, self._cmd_group)
		return self._afield

	@property
	def payload(self):
		"""payload commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_payload'):
			from .Payload import PayloadCls
			self._payload = PayloadCls(self._core, self._cmd_group)
		return self._payload

	@property
	def pid(self):
		"""pid commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_pid'):
			from .Pid import PidCls
			self._pid = PidCls(self._core, self._cmd_group)
		return self._pid

	@property
	def teIndication(self):
		"""teIndication commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_teIndication'):
			from .TeIndication import TeIndicationCls
			self._teIndication = TeIndicationCls(self._core, self._cmd_group)
		return self._teIndication

	def get_ccounter(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBS:THConfig:CCOunter \n
		Snippet: value: int = driver.source.bb.dvb.dvbs.thConfig.get_ccounter() \n
		Sets the sequence number of the first payload packet. \n
			:return: ccounter: integer Range: 0 to 15
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:DVBS:THConfig:CCOunter?')
		return Conversions.str_to_int(response)

	def set_ccounter(self, ccounter: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBS:THConfig:CCOunter \n
		Snippet: driver.source.bb.dvb.dvbs.thConfig.set_ccounter(ccounter = 1) \n
		Sets the sequence number of the first payload packet. \n
			:param ccounter: integer Range: 0 to 15
		"""
		param = Conversions.decimal_value_to_str(ccounter)
		self._core.io.write(f'SOURce<HwInstance>:BB:DVB:DVBS:THConfig:CCOunter {param}')

	def get_pus(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBS:THConfig:PUS \n
		Snippet: value: bool = driver.source.bb.dvb.dvbs.thConfig.get_pus() \n
		If enabled, the PES (packetized elementary streams) , PSI (program specific information) , or DVB-MIP (megaframe
		initialization) packet begin immediately after the header. \n
			:return: psu_indication: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:DVBS:THConfig:PUS?')
		return Conversions.str_to_bool(response)

	def set_pus(self, psu_indication: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBS:THConfig:PUS \n
		Snippet: driver.source.bb.dvb.dvbs.thConfig.set_pus(psu_indication = False) \n
		If enabled, the PES (packetized elementary streams) , PSI (program specific information) , or DVB-MIP (megaframe
		initialization) packet begin immediately after the header. \n
			:param psu_indication: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(psu_indication)
		self._core.io.write(f'SOURce<HwInstance>:BB:DVB:DVBS:THConfig:PUS {param}')

	def get_scontrol(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBS:THConfig:SCONtrol \n
		Snippet: value: int = driver.source.bb.dvb.dvbs.thConfig.get_scontrol() \n
		Sets the scrambling information. \n
			:return: scontrol: integer Range: 0 to 3
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:DVBS:THConfig:SCONtrol?')
		return Conversions.str_to_int(response)

	def set_scontrol(self, scontrol: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBS:THConfig:SCONtrol \n
		Snippet: driver.source.bb.dvb.dvbs.thConfig.set_scontrol(scontrol = 1) \n
		Sets the scrambling information. \n
			:param scontrol: integer Range: 0 to 3
		"""
		param = Conversions.decimal_value_to_str(scontrol)
		self._core.io.write(f'SOURce<HwInstance>:BB:DVB:DVBS:THConfig:SCONtrol {param}')

	def get_tpriority(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBS:THConfig:TPRiority \n
		Snippet: value: int = driver.source.bb.dvb.dvbs.thConfig.get_tpriority() \n
		Marks the current packet as high priority packet compared to packets with the same PID. \n
			:return: tpriority: integer Range: 0 to 1
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:DVBS:THConfig:TPRiority?')
		return Conversions.str_to_int(response)

	def set_tpriority(self, tpriority: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBS:THConfig:TPRiority \n
		Snippet: driver.source.bb.dvb.dvbs.thConfig.set_tpriority(tpriority = 1) \n
		Marks the current packet as high priority packet compared to packets with the same PID. \n
			:param tpriority: integer Range: 0 to 1
		"""
		param = Conversions.decimal_value_to_str(tpriority)
		self._core.io.write(f'SOURce<HwInstance>:BB:DVB:DVBS:THConfig:TPRiority {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBS:THConfig:[STATe] \n
		Snippet: value: bool = driver.source.bb.dvb.dvbs.thConfig.get_state() \n
		Inserts header information in the transport stream. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:DVBS:THConfig:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBS:THConfig:[STATe] \n
		Snippet: driver.source.bb.dvb.dvbs.thConfig.set_state(state = False) \n
		Inserts header information in the transport stream. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:DVB:DVBS:THConfig:STATe {param}')

	def clone(self) -> 'ThConfigCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ThConfigCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MimoCls:
	"""Mimo commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mimo", core, parent)

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:WLAY:PCONfig:UCONfig:MIMO:STATe \n
		Snippet: value: bool = driver.source.bb.wlay.pconfig.uconfig.mimo.get_state() \n
		Queries if the current user uses multi-user (MU) MIMO. All MU-MIMO users share one resource unit (RU) using different
		space time streams. \n
			:return: mimo_state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:WLAY:PCONfig:UCONfig:MIMO:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, mimo_state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLAY:PCONfig:UCONfig:MIMO:STATe \n
		Snippet: driver.source.bb.wlay.pconfig.uconfig.mimo.set_state(mimo_state = False) \n
		Queries if the current user uses multi-user (MU) MIMO. All MU-MIMO users share one resource unit (RU) using different
		space time streams. \n
			:param mimo_state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(mimo_state)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLAY:PCONfig:UCONfig:MIMO:STATe {param}')



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TmphCls:
	"""Tmph commands group definition. 6 total commands, 6 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tmph", core, parent)

	@property
	def ctOffset(self):
		"""ctOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ctOffset'):
			from .CtOffset import CtOffsetCls
			self._ctOffset = CtOffsetCls(self._core, self._cmd_group)
		return self._ctOffset

	@property
	def phOffset(self):
		"""phOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_phOffset'):
			from .PhOffset import PhOffsetCls
			self._phOffset = PhOffsetCls(self._core, self._cmd_group)
		return self._phOffset

	@property
	def sfOffset(self):
		"""sfOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sfOffset'):
			from .SfOffset import SfOffsetCls
			self._sfOffset = SfOffsetCls(self._core, self._cmd_group)
		return self._sfOffset

	@property
	def ssbtOffset(self):
		"""ssbtOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ssbtOffset'):
			from .SsbtOffset import SsbtOffsetCls
			self._ssbtOffset = SsbtOffsetCls(self._core, self._cmd_group)
		return self._ssbtOffset

	@property
	def syfnOffset(self):
		"""syfnOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_syfnOffset'):
			from .SyfnOffset import SyfnOffsetCls
			self._syfnOffset = SyfnOffsetCls(self._core, self._cmd_group)
		return self._syfnOffset

	@property
	def taOffset(self):
		"""taOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_taOffset'):
			from .TaOffset import TaOffsetCls
			self._taOffset = TaOffsetCls(self._core, self._cmd_group)
		return self._taOffset

	def clone(self) -> 'TmphCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TmphCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ScmdCls:
	"""Scmd commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("scmd", core, parent)

	def set(self, scmd: enums.NfcSelCmd, commandBlock=repcap.CommandBlock.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NFC:CBLock<CH>:SCMD \n
		Snippet: driver.source.bb.nfc.cblock.scmd.set(scmd = enums.NfcSelCmd.CL1, commandBlock = repcap.CommandBlock.Default) \n
		Selects the cascade level (CL) of the NFCID1 requested by the NFC Forum Device in Poll Mode. \n
			:param scmd: CL1| CL2| CL3
			:param commandBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')
		"""
		param = Conversions.enum_scalar_to_str(scmd, enums.NfcSelCmd)
		commandBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(commandBlock, repcap.CommandBlock)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:CBLock{commandBlock_cmd_val}:SCMD {param}')

	# noinspection PyTypeChecker
	def get(self, commandBlock=repcap.CommandBlock.Default) -> enums.NfcSelCmd:
		"""SCPI: [SOURce<HW>]:BB:NFC:CBLock<CH>:SCMD \n
		Snippet: value: enums.NfcSelCmd = driver.source.bb.nfc.cblock.scmd.get(commandBlock = repcap.CommandBlock.Default) \n
		Selects the cascade level (CL) of the NFCID1 requested by the NFC Forum Device in Poll Mode. \n
			:param commandBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')
			:return: scmd: CL1| CL2| CL3"""
		commandBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(commandBlock, repcap.CommandBlock)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NFC:CBLock{commandBlock_cmd_val}:SCMD?')
		return Conversions.str_to_scalar_enum(response, enums.NfcSelCmd)



from .............Internal.Core import Core
from .............Internal.CommandsGroup import CommandsGroup
from .............Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UtcCls:
	"""Utc commands group definition. 7 total commands, 3 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("utc", core, parent)

	@property
	def aone(self):
		"""aone commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_aone'):
			from .Aone import AoneCls
			self._aone = AoneCls(self._core, self._cmd_group)
		return self._aone

	@property
	def azero(self):
		"""azero commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_azero'):
			from .Azero import AzeroCls
			self._azero = AzeroCls(self._core, self._cmd_group)
		return self._azero

	@property
	def tot(self):
		"""tot commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_tot'):
			from .Tot import TotCls
			self._tot = TotCls(self._core, self._cmd_group)
		return self._tot

	def get_wnot(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SV:SBAS:WAAS:NMESsage:NAV:TIME:CONVersion:UTC:WNOT \n
		Snippet: value: int = driver.source.bb.gnss.sv.sbas.waas.nmessage.nav.time.conversion.utc.get_wnot() \n
		Sets the parameter WNot. \n
			:return: wnot: integer Range: 0 to 529947
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:SV:SBAS:WAAS:NMESsage:NAV:TIME:CONVersion:UTC:WNOT?')
		return Conversions.str_to_int(response)

	def set_wnot(self, wnot: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SV:SBAS:WAAS:NMESsage:NAV:TIME:CONVersion:UTC:WNOT \n
		Snippet: driver.source.bb.gnss.sv.sbas.waas.nmessage.nav.time.conversion.utc.set_wnot(wnot = 1) \n
		Sets the parameter WNot. \n
			:param wnot: integer Range: 0 to 529947
		"""
		param = Conversions.decimal_value_to_str(wnot)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:SV:SBAS:WAAS:NMESsage:NAV:TIME:CONVersion:UTC:WNOT {param}')

	def clone(self) -> 'UtcCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = UtcCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



"""RsSmw instrument driver
	:version: 5.30.47.79
	:copyright: 2023 by Rohde & Schwarz GMBH & Co. KG
	:license: MIT, see LICENSE for more details.
"""

__version__ = '5.30.47.79'

# Main class
from RsSmw.RsSmw import RsSmw

# Bin data format
from RsSmw.Internal.Conversions import BinIntFormat, BinFloatFormat

# Exceptions
from RsSmw.Internal.InstrumentErrors import RsInstrException, TimeoutException, StatusException, UnexpectedResponseException, ResourceError, DriverValueError

# Callback Event Argument prototypes
from RsSmw.Internal.IoTransferEventArgs import IoTransferEventArgs

# Logging Mode
from RsSmw.Internal.ScpiLogger import LoggingMode

# enums
from RsSmw import enums

# repcaps
from RsSmw import repcap



from ............Internal.Core import Core
from ............Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ResCls:
	"""Res commands group definition. 19 total commands, 19 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("res", core, parent)

	@property
	def amcs(self):
		"""amcs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_amcs'):
			from .Amcs import AmcsCls
			self._amcs = AmcsCls(self._core, self._cmd_group)
		return self._amcs

	@property
	def bof1(self):
		"""bof1 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bof1'):
			from .Bof1 import Bof1Cls
			self._bof1 = Bof1Cls(self._core, self._cmd_group)
		return self._bof1

	@property
	def bof2(self):
		"""bof2 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bof2'):
			from .Bof2 import Bof2Cls
			self._bof2 = Bof2Cls(self._core, self._cmd_group)
		return self._bof2

	@property
	def bof3(self):
		"""bof3 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bof3'):
			from .Bof3 import Bof3Cls
			self._bof3 = Bof3Cls(self._core, self._cmd_group)
		return self._bof3

	@property
	def bof4(self):
		"""bof4 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bof4'):
			from .Bof4 import Bof4Cls
			self._bof4 = Bof4Cls(self._core, self._cmd_group)
		return self._bof4

	@property
	def indicator(self):
		"""indicator commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_indicator'):
			from .Indicator import IndicatorCls
			self._indicator = IndicatorCls(self._core, self._cmd_group)
		return self._indicator

	@property
	def mnPres(self):
		"""mnPres commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mnPres'):
			from .MnPres import MnPresCls
			self._mnPres = MnPresCls(self._core, self._cmd_group)
		return self._mnPres

	@property
	def mreserve(self):
		"""mreserve commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mreserve'):
			from .Mreserve import MreserveCls
			self._mreserve = MreserveCls(self._core, self._cmd_group)
		return self._mreserve

	@property
	def mscTable(self):
		"""mscTable commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mscTable'):
			from .MscTable import MscTableCls
			self._mscTable = MscTableCls(self._core, self._cmd_group)
		return self._mscTable

	@property
	def nprb(self):
		"""nprb commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nprb'):
			from .Nprb import NprbCls
			self._nprb = NprbCls(self._core, self._cmd_group)
		return self._nprb

	@property
	def nsubChannels(self):
		"""nsubChannels commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nsubChannels'):
			from .NsubChannels import NsubChannelsCls
			self._nsubChannels = NsubChannelsCls(self._core, self._cmd_group)
		return self._nsubChannels

	@property
	def pat2(self):
		"""pat2 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pat2'):
			from .Pat2 import Pat2Cls
			self._pat2 = Pat2Cls(self._core, self._cmd_group)
		return self._pat2

	@property
	def pat3(self):
		"""pat3 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pat3'):
			from .Pat3 import Pat3Cls
			self._pat3 = Pat3Cls(self._core, self._cmd_group)
		return self._pat3

	@property
	def pat4(self):
		"""pat4 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pat4'):
			from .Pat4 import Pat4Cls
			self._pat4 = Pat4Cls(self._core, self._cmd_group)
		return self._pat4

	@property
	def repList(self):
		"""repList commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_repList'):
			from .RepList import RepListCls
			self._repList = RepListCls(self._core, self._cmd_group)
		return self._repList

	@property
	def resBits(self):
		"""resBits commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_resBits'):
			from .ResBits import ResBitsCls
			self._resBits = ResBitsCls(self._core, self._cmd_group)
		return self._resBits

	@property
	def scaling(self):
		"""scaling commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scaling'):
			from .Scaling import ScalingCls
			self._scaling = ScalingCls(self._core, self._cmd_group)
		return self._scaling

	@property
	def schSize(self):
		"""schSize commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_schSize'):
			from .SchSize import SchSizeCls
			self._schSize = SchSizeCls(self._core, self._cmd_group)
		return self._schSize

	@property
	def strb(self):
		"""strb commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_strb'):
			from .Strb import StrbCls
			self._strb = StrbCls(self._core, self._cmd_group)
		return self._strb

	def clone(self) -> 'ResCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ResCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NameCls:
	"""Name commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("name", core, parent)

	def get_detailed(self) -> str:
		"""SCPI: SYSTem:LOCK:NAME:DETailed \n
		Snippet: value: str = driver.system.lock.name.get_detailed() \n
		No command help available \n
			:return: details: No help available
		"""
		response = self._core.io.query_str('SYSTem:LOCK:NAME:DETailed?')
		return trim_str_response(response)

	def get_value(self) -> str:
		"""SCPI: SYSTem:LOCK:NAME \n
		Snippet: value: str = driver.system.lock.name.get_value() \n
		No command help available \n
			:return: name: No help available
		"""
		response = self._core.io.query_str('SYSTem:LOCK:NAME?')
		return trim_str_response(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RxCls:
	"""Rx commands group definition. 9 total commands, 6 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rx", core, parent)

	@property
	def antenna(self):
		"""antenna commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_antenna'):
			from .Antenna import AntennaCls
			self._antenna = AntennaCls(self._core, self._cmd_group)
		return self._antenna

	@property
	def calc(self):
		"""calc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_calc'):
			from .Calc import CalcCls
			self._calc = CalcCls(self._core, self._cmd_group)
		return self._calc

	@property
	def column(self):
		"""column commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_column'):
			from .Column import ColumnCls
			self._column = ColumnCls(self._core, self._cmd_group)
		return self._column

	@property
	def espacing(self):
		"""espacing commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_espacing'):
			from .Espacing import EspacingCls
			self._espacing = EspacingCls(self._core, self._cmd_group)
		return self._espacing

	@property
	def polarization(self):
		"""polarization commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_polarization'):
			from .Polarization import PolarizationCls
			self._polarization = PolarizationCls(self._core, self._cmd_group)
		return self._polarization

	@property
	def rows(self):
		"""rows commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rows'):
			from .Rows import RowsCls
			self._rows = RowsCls(self._core, self._cmd_group)
		return self._rows

	# noinspection PyTypeChecker
	def get_pattern(self) -> enums.AntMod3DaNtPattern:
		"""SCPI: [SOURce]:FSIMulator:MIMO:ANTenna:RX:PATTern \n
		Snippet: value: enums.AntMod3DaNtPattern = driver.source.fsimulator.mimo.antenna.rx.get_pattern() \n
		Sets the antenna pattern mode. \n
			:return: ant_rx_patt_descr: No help available
		"""
		response = self._core.io.query_str('SOURce:FSIMulator:MIMO:ANTenna:RX:PATTern?')
		return Conversions.str_to_scalar_enum(response, enums.AntMod3DaNtPattern)

	def set_pattern(self, ant_rx_patt_descr: enums.AntMod3DaNtPattern) -> None:
		"""SCPI: [SOURce]:FSIMulator:MIMO:ANTenna:RX:PATTern \n
		Snippet: driver.source.fsimulator.mimo.antenna.rx.set_pattern(ant_rx_patt_descr = enums.AntMod3DaNtPattern.DIPole) \n
		Sets the antenna pattern mode. \n
			:param ant_rx_patt_descr: ISOtropic| USER| SEC3| SEC6| DIPole| DPISotripic
		"""
		param = Conversions.enum_scalar_to_str(ant_rx_patt_descr, enums.AntMod3DaNtPattern)
		self._core.io.write(f'SOURce:FSIMulator:MIMO:ANTenna:RX:PATTern {param}')

	def clone(self) -> 'RxCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RxCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PucchCls:
	"""Pucch commands group definition. 12 total commands, 10 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pucch", core, parent)

	@property
	def a12List(self):
		"""a12List commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_a12List'):
			from .A12List import A12ListCls
			self._a12List = A12ListCls(self._core, self._cmd_group)
		return self._a12List

	@property
	def adMrs(self):
		"""adMrs commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_adMrs'):
			from .AdMrs import AdMrsCls
			self._adMrs = AdMrsCls(self._core, self._cmd_group)
		return self._adMrs

	@property
	def bpsk(self):
		"""bpsk commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_bpsk'):
			from .Bpsk import BpskCls
			self._bpsk = BpskCls(self._core, self._cmd_group)
		return self._bpsk

	@property
	def brind(self):
		"""brind commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_brind'):
			from .Brind import BrindCls
			self._brind = BrindCls(self._core, self._cmd_group)
		return self._brind

	@property
	def cpext(self):
		"""cpext commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_cpext'):
			from .Cpext import CpextCls
			self._cpext = CpextCls(self._core, self._cmd_group)
		return self._cpext

	@property
	def hack(self):
		"""hack commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_hack'):
			from .Hack import HackCls
			self._hack = HackCls(self._core, self._cmd_group)
		return self._hack

	@property
	def pdsharq(self):
		"""pdsharq commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_pdsharq'):
			from .Pdsharq import PdsharqCls
			self._pdsharq = PdsharqCls(self._core, self._cmd_group)
		return self._pdsharq

	@property
	def u2Tpc(self):
		"""u2Tpc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_u2Tpc'):
			from .U2Tpc import U2TpcCls
			self._u2Tpc = U2TpcCls(self._core, self._cmd_group)
		return self._u2Tpc

	@property
	def uitl(self):
		"""uitl commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_uitl'):
			from .Uitl import UitlCls
			self._uitl = UitlCls(self._core, self._cmd_group)
		return self._uitl

	@property
	def ur16(self):
		"""ur16 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ur16'):
			from .Ur16 import Ur16Cls
			self._ur16 = Ur16Cls(self._core, self._cmd_group)
		return self._ur16

	def clone(self) -> 'PucchCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PucchCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group
